@@ -76,6 +76,10 @@ debug = '--debug' in sys.argv or '-g' in sys.argv
 lflags_arg = []
 
 
+# Supported Oracle Berkeley DB versions, in order of preference.
+db_ver_list = ((18, 1), (6, 2), (5, 3), (4, 8))
+db_ver = None
+
 if os.name == 'posix':
     # Allow setting the DB dir and additional link flags either in
     # the environment or on the command line.
@@ -109,10 +113,6 @@ if os.name == 'posix':
     if LFLAGS or LIBS:
         lflags_arg = LFLAGS + LIBS
 
-    # Supported Oracle Berkeley DB versions, in order of preference.
-    db_ver_list = ((18, 1), (6, 2), (5, 3), (4, 8))
-    db_ver = None
-
     # If we were not told where it is, go looking for it.
     dblib = 'db'
     incdir = libdir = None
@@ -319,11 +319,68 @@ if os.name == 'posix':
     print('Detected Oracle Berkeley DB version %d.%d from db.h' %db_ver)
 
 elif os.name == 'nt':
-    print()
-    print('MS Windows is unsupported. I you need it, please let me know!')
-    print()
-    sys.exit(1)
+    # The default build of Oracle Berkeley DB for windows just leaves
+    # everything in the build dirs in the db source tree. That means
+    # that we either have to hunt around to find it, (which would be
+    # even more difficult than the mess above for Unix...) or we make
+    # the builder specify everything here. Compounding the problem is
+    # version numbers in default path names, and different library
+    # names for debug/release or dll/static.
+    #
+    # So to make things easier, I'm just going to expect that the DB stuff
+    # has been moved to the ./db directory. There's an updatedb.bat file to
+    # help.
+    #
+    # You'll need to edit the project file that comes with Oracle Berkeley DB
+    # so it uses "Multithreaded DLL" and "Debug Multithreaded DLL"  (/MD and
+    # /MDd) settings as appropriate to build .lib file (the db_static
+    # project).
 
+    incdir = 'db/include'
+    libdir = 'db/lib'
+
+    # read db.h to figure out what version of Oracle Berkeley DB this is
+    ver = None
+    with open(os.path.join(incdir, 'db.h'), 'r') as f :
+        db_h_lines = f.readlines()
+    db_ver_re = re.compile(
+        r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
+    for line in db_h_lines:
+        match = db_ver_re.match(line)
+        if not match:
+            continue
+        fullverstr = match.group(1)
+        ver = fullverstr.split('.')
+        db_ver = (int(ver[0]), int(ver[1]))
+    if db_ver not in db_ver_list:
+        raise AssertionError(
+                'berkeleydb untested with this Oracle Berkeley DB '
+                'version %d.%d' %db_ver)
+    print('Detected Oracle Berkeley DB version %d.%d from db.h' %db_ver)
+
+    dep_libs = ['ws2_32', 'Advapi32'] # WIN32 dependencies
+
+    if debug:
+        # Debug, static
+        libname = ['libdb%s%ssd' % (ver[0], ver[1])] + dep_libs
+    else:
+        # Release, static
+        libname = ['libdb%s%ss' % (ver[0], ver[1])] + dep_libs
+
+    utils = [("berkeleydb/utils",
+              ["db/bin/db_archive.exe",
+               "db/bin/db_checkpoint.exe",
+               "db/bin/db_deadlock.exe",
+               "db/bin/db_dump.exe",
+               "db/bin/db_load.exe",
+               "db/bin/db_printlog.exe",
+               "db/bin/db_recover.exe",
+               "db/bin/db_stat.exe",
+               "db/bin/db_upgrade.exe",
+               "db/bin/db_verify.exe",
+               "db/bin/libdb%s%s.dll" % (ver[0], ver[1]),
+               ]),
+             ]
 else:
     print()
     print(f'"{os.name}" is unsupported. I you need it, please let me know!')
@@ -397,6 +454,21 @@ del config_vars
 
 # do the actual build, install, whatever...
 
+ext_modules_params = {
+                         'sources': ['src/Module/berkeleydb.c'],
+                         'depends': ['src/Module/berkeleydb.h'],
+                         'include_dirs': [ incdir ],
+                         'library_dirs': [ libdir ],
+                         'libraries': libname,
+                         'extra_link_args': lflags_arg,
+                         'py_limited_api': True,
+                     }
+
+if os.name == 'posix':
+    ext_modules_params['runtime_library_dirs'] = [ libdir ]
+
+ext_modules = [Extension('berkeleydb._berkeleydb', **ext_modules_params)]
+
 kw_params = dict(
       name = 'berkeleydb',
       version = VERSION,
@@ -432,16 +504,7 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
 
       packages = ['berkeleydb'],
       package_dir = {'berkeleydb': 'src/berkeleydb'},
-      ext_modules = [Extension('berkeleydb._berkeleydb',
-                               sources = ['src/Module/berkeleydb.c'],
-                               depends = ['src/Module/berkeleydb.h'],
-                               include_dirs = [ incdir ],
-                               library_dirs = [ libdir ],
-                               runtime_library_dirs = [ libdir ],
-                               libraries = libname,
-                               extra_link_args = lflags_arg,
-                               py_limited_api = True,
-                               )],
+      ext_modules = ext_modules,
       headers = ['src/Module/berkeleydb.h'],
       data_files = utils,
       classifiers = [
@@ -452,6 +515,8 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
                     'Natural Language :: English',
                     'Natural Language :: Spanish',
                     'Operating System :: Unix',
+                    'Operating System :: POSIX',
+                    'Operating System :: Microsoft :: Windows',
                     'Programming Language :: Python',
                     'Topic :: Database',
                     'Topic :: Software Development',
