@@ -457,7 +457,7 @@ def process_args(argv=None):
         # the parameter "extra_compile_args".
         if 'CFLAGS' not in os.environ:
             os.environ['CFLAGS'] = '-Wall -Werror -Wextra ' \
-                      '-Wno-cast-function-type'
+                      '-Wno-error=cast-function-type -Wno-cast-function-type'
 
         cmd = sys.executable + ' setup.py build'
         sts = os.system(cmd)
