@@ -57,6 +57,27 @@ class VersionTestCase(unittest.TestCase):
         self.assertEqual(info, (db.DB_VERSION_MAJOR, db.DB_VERSION_MINOR,
                         db.DB_VERSION_PATCH))
 
+class Log_statTestCase(unittest.TestCase):
+    def test01_log_stat(self):
+        env = db.DBEnv()
+        try:
+            homeDir = get_new_environment_path()
+            env.open(homeDir, db.DB_INIT_LOG | db.DB_CREATE)
+            stats = env.log_stat()
+        finally:
+            rmtree(homeDir)
+            env.close()
+
+        if db.version() >= (5, 3):
+            self.assertEqual(len(stats), 26)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stats), 23)
+        else:
+            raise RuntimeError('Unknown Berkeley DB version')
+
+        self.assertIn('regsize', stats)
+        self.assertIn('disk_file', stats)
+
 #----------------------------------------------------------------------
 
 class BasicTestCase(unittest.TestCase):
@@ -160,6 +181,11 @@ class BasicTestCase(unittest.TestCase):
     def test01_GetsAndPuts(self):
         d = self.d
 
+        self.assertRaisesRegex(TypeError,
+                               'Bytes or Integer object expected for key, '
+                               'str found',
+                               d.get, '1234')
+
         for key in [b'0001', b'0100', b'0400', b'0700', b'0999']:
             data = d.get(key)
 
@@ -1340,7 +1366,7 @@ class open_path(unittest.TestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    for test in (VersionTestCase,
+    for test in (VersionTestCase, Log_statTestCase,
                     BasicBTreeTestCase,
                     BasicHashTestCase,
                     BasicBTreeWithThreadFlagTestCase,
