@@ -92,7 +92,13 @@ class DBEnv_general(DBEnv) :
         self.env.open(self.homeDir, db.DB_CREATE | db.DB_INIT_MPOOL |
                 db.DB_INIT_LOCK)
         stat = self.env.mutex_stat()
-        self.assertTrue("mutex_inuse_max" in stat)
+        if db.version() >= (5, 3):
+            self.assertEqual(len(stat), 12)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stat), 9)
+        else:
+            raise RuntimeError('Unknown Berkeley DB version')
+        self.assertIn('mutex_inuse_max', stat)
 
     def test_lg_filemode(self) :
         for i in [0o600, 0o660, 0o666] :
@@ -382,6 +388,17 @@ class DBEnv_log_txn(DBEnv) :
             for i in txns :
                 i.abort()
 
+    def test_txn_stat(self):
+        stats = self.env.txn_stat()
+        if db.version() >= (5, 3):
+            self.assertEqual(len(stats), 16)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stats), 15)
+        else:
+            raise RuntimeError('Unknown Berkeley DB version')
+
+        self.assertIn('time_ckp', stats)
+
     # The version without transactions is checked in other test object
     def test_log_printf(self) :
         msg = b'This is a test...'
@@ -455,6 +472,25 @@ class DBEnv_memp(DBEnv):
         self.assertTrue("test" in stats)
         self.assertTrue("page_in" in stats["test"])
 
+    def test_memp_stat_3(self):
+        stats = self.env.memp_stat()
+        if db.version() >= (6, 2):
+            self.assertEqual(len(stats[0]), 45)
+        elif db.version() >= (5, 3):
+            self.assertEqual(len(stats[0]), 44)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stats[0]), 42)
+        else:
+            raise RuntimeError('Unknown Berkeley DB version')
+
+        self.assertEqual(len(stats[1]), 1)
+        self.assertIn('test', stats[1])
+
+        if db.version() >= (5, 3):
+            self.assertEqual(len(stats[1]['test']), 8)
+        else:
+            self.assertEqual(len(stats[1]['test']), 7)
+
 
 class DBEnv_memp_stat_no_db(DBEnv):
     def setUp(self):
