@@ -80,37 +80,37 @@ class DBEnvEncryption(unittest.TestCase):
         self.assertRaises(db.DBInvalidArgError, self.dbenv.set_encrypt, '')
 
     def test03_key_string(self):
-        self.dbenv.set_encrypt('abc')
+        self.dbenv.set_encrypt(self.key1)
         flags = self.dbenv.get_encrypt_flags()
         self.assertEqual(flags, 0)
 
     def test04_key_string_flags(self):
-        self.dbenv.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.dbenv.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         flags = self.dbenv.get_encrypt_flags()
         self.assertEqual(flags, db.DB_ENCRYPT_AES)
 
     def test05_reopen_different_keys(self):
-        self.dbenv.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.dbenv.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.dbenv)
         dbenv2 = db.DBEnv()
         try:
-            dbenv2.set_encrypt('XXX', flags=db.DB_ENCRYPT_AES)
+            dbenv2.set_encrypt(self.key2, flags=db.DB_ENCRYPT_AES)
             self.assertRaises(db.DBPermissionsError, self._open, dbenv2)
         finally:
             dbenv2.close()
 
     def test06_reopen_same_key(self):
-        self.dbenv.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.dbenv.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.dbenv)
         dbenv2 = db.DBEnv()
         try:
-            dbenv2.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+            dbenv2.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
             self._open(dbenv2)
         finally:
             dbenv2.close()
 
     def test07_reopen_no_key(self):
-        self.dbenv.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.dbenv.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.dbenv)
         dbenv2 = db.DBEnv()
         try:
@@ -122,7 +122,7 @@ class DBEnvEncryption(unittest.TestCase):
         self._open(self.dbenv)
         dbenv2 = db.DBEnv()
         try:
-            dbenv2.set_encrypt('XXX', flags=db.DB_ENCRYPT_AES)
+            dbenv2.set_encrypt(self.key2, flags=db.DB_ENCRYPT_AES)
             self.assertRaises(db.DBInvalidArgError, self._open, dbenv2)
         finally:
             dbenv2.close()
@@ -141,16 +141,41 @@ class DBEnvEncryption(unittest.TestCase):
         database = db.DB(self.dbenv)
         try:
             self.assertRaises(db.DBInvalidArgError, database.set_encrypt,
-                              'XXX', flags=db.DB_ENCRYPT_AES)
+                              self.key2, flags=db.DB_ENCRYPT_AES)
         finally:
             database.close()
 
-    def test11_invalid_key(self):
+    def test11_key_with_nulls(self):
         # Password can not contains NULL characters.
-        self.assertRaises(ValueError, self.dbenv.set_encrypt, '\x00')
-        self.assertRaises(ValueError, self.dbenv.set_encrypt, '\x00',
+        key = '\x00'
+        if isinstance(self.key1, bytes):
+            key = b'\x00'
+        self.assertRaises(ValueError, self.dbenv.set_encrypt, key)
+        self.assertRaises(ValueError, self.dbenv.set_encrypt, key,
                           flags=db.DB_ENCRYPT_AES)
 
+    def test12_key_invalid_types(self):
+        for v in (17, None, bytearray(b'a')):
+            self.assertRaisesRegex(TypeError,
+                                   'Expected string or bytes argument, '
+                                   fr'{type(v).__name__} found\.',
+                                   self.dbenv.set_encrypt, v)
+            self.assertRaisesRegex(TypeError,
+                                   'Expected string or bytes argument, '
+                                   fr'{type(v).__name__} found\.',
+                                   self.dbenv.set_encrypt, v,
+                                   flags=db.DB_ENCRYPT_AES)
+
+
+class DBEnvEncryption_utf8(DBEnvEncryption):
+    key1 = 'abc'
+    key2 = 'XXX'
+
+
+class DBEnvEncryption_binary(DBEnvEncryption):
+    key1 = b'abc'
+    key2 = b'XXX'
+
 
 @unittest.skipUnless(encryption_supported,
                      'Berkeley DB was compiled without encryption support')
@@ -175,21 +200,21 @@ class DBEncryption(unittest.TestCase):
         self.assertRaises(db.DBInvalidArgError, self.db.set_encrypt, '')
 
     def test03_key_string(self):
-        self.db.set_encrypt('abc')
+        self.db.set_encrypt(self.key1)
         flags = self.db.get_encrypt_flags()
         self.assertEqual(flags, 0)
 
     def test04_key_string_flags(self):
-        self.db.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.db.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         flags = self.db.get_encrypt_flags()
         self.assertEqual(flags, db.DB_ENCRYPT_AES)
 
     def test05_reopen_different_keys(self):
-        self.db.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.db.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.db)
         db2 = db.DB()
         try:
-            db2.set_encrypt('XXX', flags=db.DB_ENCRYPT_AES)
+            db2.set_encrypt(self.key2, flags=db.DB_ENCRYPT_AES)
             if db.version() >= (5, 3):
                 self.assertRaises(db.DBInvalidArgError, self._open, db2)
             else:
@@ -201,17 +226,17 @@ class DBEncryption(unittest.TestCase):
             db2.close()
 
     def test06_reopen_same_key(self):
-        self.db.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.db.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.db)
         db2 = db.DB()
         try:
-            db2.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+            db2.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
             self._open(db2)
         finally:
             db2.close()
 
     def test07_reopen_no_key(self):
-        self.db.set_encrypt('abc', flags=db.DB_ENCRYPT_AES)
+        self.db.set_encrypt(self.key1, flags=db.DB_ENCRYPT_AES)
         self._open(self.db)
         db2 = db.DB()
         try:
@@ -223,23 +248,47 @@ class DBEncryption(unittest.TestCase):
         self._open(self.db)
         db2 = db.DB()
         try:
-            db2.set_encrypt('XXX', flags=db.DB_ENCRYPT_AES)
+            db2.set_encrypt(self.key2, flags=db.DB_ENCRYPT_AES)
             self.assertRaises(db.DBInvalidArgError, self._open, db2)
         finally:
             db2.close()
 
-    def test09_invalid_key(self):
+    def test09_key_with_nulls(self):
         # Password can not contains NULL characters.
-        self.assertRaises(ValueError, self.db.set_encrypt, '\x00')
-        self.assertRaises(ValueError, self.db.set_encrypt, '\x00',
+        key = '\x00'
+        if isinstance(self.key1, bytes):
+            key = b'\x00'
+        self.assertRaises(ValueError, self.db.set_encrypt, key)
+        self.assertRaises(ValueError, self.db.set_encrypt, key,
                           flags=db.DB_ENCRYPT_AES)
 
+    def test10_key_invalid_types(self):
+        for v in (17, None, bytearray(b'a')):
+            self.assertRaisesRegex(TypeError,
+                                   'Expected string or bytes argument, '
+                                   fr'{type(v).__name__} found\.',
+                                   self.db.set_encrypt, v)
+            self.assertRaisesRegex(TypeError,
+                                   'Expected string or bytes argument, '
+                                   fr'{type(v).__name__} found\.',
+                                   self.db.set_encrypt, v,
+                                   flags=db.DB_ENCRYPT_AES)
+
+
+class DBEncryption_utf8(DBEncryption):
+    key1 = 'abc'
+    key2 = 'XXX'
+
+class DBEncryption_binary(DBEncryption):
+    key1 = b'abc'
+    key2 = b'XXX'
 
 #----------------------------------------------------------------------
 
 def test_suite():
     suite = unittest.TestSuite()
-    for test in (DBEnvEncryption, DBEncryption):
+    for test in (DBEnvEncryption_utf8, DBEnvEncryption_binary,
+                 DBEncryption_utf8, DBEncryption_binary):
         test = unittest.defaultTestLoader.loadTestsFromTestCase(test)
         suite.addTest(test)
 
