@@ -283,6 +283,24 @@ class DBReplicationManager(DBReplication) :
         self.assertTrue(time.time()<timeout)
         self.assertEqual(None, v)
 
+    def test02_repmgr_stat(self) :
+        stat = self.dbenvMaster.repmgr_stat()
+        if db.version() >= (18, 1):
+            self.assertEqual(len(stat), 18)
+            self.assertIn('group_stable_log_file', stat)
+        elif db.version() >= (6, 2):
+            self.assertEqual(len(stat), 16)
+            self.assertIn('takeovers', stat)
+        elif db.version() >= (5, 3):
+            self.assertEqual(len(stat), 7)
+            self.assertIn('elect_threads', stat)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stat), 5)
+        else:
+            raise RuntimeError('Unknown Berkeley DB version')
+
+        self.assertIn('connection_drop', stat)
+
 class DBBaseReplication(DBReplication) :
     def setUp(self) :
         super().setUp()
@@ -524,6 +542,19 @@ class DBBaseReplication(DBReplication) :
                 self.dbenvMaster.rep_get_clockskew())
         self.basic_rep_threading()
 
+    def test05_rep_stat(self):
+        self.basic_rep_threading()
+        stat = self.dbenvMaster.rep_stat()
+        if db.version() >= (6, 2):
+            self.assertEqual(len(stat), 66)
+        elif db.version() >= (5, 3):
+            self.assertEqual(len(stat), 61)
+        elif db.version() >= (4, 8):
+            self.assertEqual(len(stat), 56)
+
+        self.assertIn('msgs_send_failures', stat)
+
+
 #----------------------------------------------------------------------
 
 def test_suite():
